Skip to contents

A historical processed representation of the single-cell RNA-seq data from Buettner et al. (2015). The object contains 182 cells, one cell-cycle label, and 8,989 numeric feature columns. Feature names are positional because the exact historical preprocessing script used to create this bundled object is unavailable.

Usage

data_cell_cycle

Format

A tibble with 182 rows and 8,990 variables:

Cell_cycle

Character cell-cycle label (G1, G2M, or S).

1–8989

Numeric processed RNA-seq features.

ArrayExpress accession E-MTAB-2805.

References

Buettner F, Natarajan KN, Casale FP, et al. (2015). Computational analysis of cell-to-cell heterogeneity in single-cell RNA-sequencing data reveals hidden subpopulations of cells. Nature Biotechnology, 33, 155–160. doi:10.1038/nbt.3102 .