Skip to contents

This helper function is useful for determining which distances to input into precise_dist. If this list of distances is not sufficient see, precise_func_fact.

Usage

precise_dist_list(dists)

Arguments

dists

A string (or character vector) of the dists to view. Options include the family keywords "all_dists", "static_dists", "binary_dists", "nominal_dists", "minkowski_dists", "l1_dists", "intersection_dists", "inner_product_dists", "squared_dists", "correlation_dists", "other_dists", "rf_dists", "kernel_dists", "tsne_dists", "probability_dists", "time_series_dists" and "transport_dists"; short aliases without "_dists" are also accepted (for example, "static" is equivalent to "static_dists"). Individual metric names and aliases are also accepted. Only metrics whose backend package is installed are returned.

Value

A list of the (canonical) distance names chosen.

Details

Some distances have more than one argument, which is generally reflected in the name:

  • Any distance with a trailing "_phil" comes from the philentropy package. This specific designation is included because the results of these distances sometimes differ from their proxy-package counterpart.

  • minkowski_0.5 refers to the minkowski dist with a power of 0.5

  • random_forest_sqrt refers to a randomForest similarity where mtry = sqrt(ncol(data)) and ntree = 1501

  • laplace_1 and rbf_1 refer dots where sigma = kernlab::sigest(as.matrix(x), scale = FALSE, frac = 1)[[1]] and this represents the 0.1 quantile for the estimate of the sigma parameter.

  • tsne_5 refers to x2p run with perplexity = 5. This result is then directly fed to p2sp.

References

Muchmore, B., Muchmore P. and Alarcón-Riquelme ME. (2018). Optimal Distance Matrix Construction with PreciseDist and PreciseGraph.

David Meyer and Christian Buchta (2018). proxy: Distance and Similarity Measures. R package version 0.4-22. https://CRAN.R-project.org/package=proxy

Hajk-Georg Drost (2018). philentropy: Similarity and Distance Quantification Between Probability Functions. R package version 0.1.0. https://CRAN.R-project.org/package=philentropy

Alexandros Karatzoglou, Alex Smola, Kurt Hornik, Achim Zeileis (2004). kernlab - An S4 Package for Kernel Methods in R. Journal of Statistical Software 11(9), 1-20. URL http://www.jstatsoft.org/v11/i09/

A. Liaw and M. Wiener (2002). Classification and Regression by randomForest. R News 2(3), 18–22.

Benjamin J. Radford (2017). mmtsne: Multiple Maps t-SNE. R package version 0.1.0. https://CRAN.R-project.org/package=mmtsne

Author

Brian Muchmore

Examples

precise_dist_list("all_dists") %>%
  as.matrix()
#>       [,1]                
#>  [1,] "euclidean"         
#>  [2,] "supremum"          
#>  [3,] "manhattan"         
#>  [4,] "minkowski_0.5"     
#>  [5,] "minkowski_1.5"     
#>  [6,] "minkowski_2.5"     
#>  [7,] "sorensen"          
#>  [8,] "gower"             
#>  [9,] "gower_phil"        
#> [10,] "soergel"           
#> [11,] "soergel_phil"      
#> [12,] "kulczynski_d"      
#> [13,] "canberra"          
#> [14,] "canberra_phil"     
#> [15,] "lorentzian"        
#> [16,] "wave"              
#> [17,] "wavehedges"        
#> [18,] "intersection"      
#> [19,] "non_intersection"  
#> [20,] "czekanowski"       
#> [21,] "tanimoto"          
#> [22,] "ruzicka"           
#> [23,] "inner_product"     
#> [24,] "harmonic_mean"     
#> [25,] "cosine"            
#> [26,] "fjaccard"          
#> [27,] "ejaccard"          
#> [28,] "edice"             
#> [29,] "dice"              
#> [30,] "squared_euclidean" 
#> [31,] "squared_chi"       
#> [32,] "divergence"        
#> [33,] "clark"             
#> [34,] "additive_symm"     
#> [35,] "correlation"       
#> [36,] "mahalanobis"       
#> [37,] "bray"              
#> [38,] "chord"             
#> [39,] "geodesic"          
#> [40,] "whittaker"         
#> [41,] "avg"               
#> [42,] "random_forest_sqrt"
#> [43,] "random_forest_two" 
#> [44,] "random_forest_half"
#> [45,] "laplace_1"         
#> [46,] "laplace_2"         
#> [47,] "laplace_3"         
#> [48,] "rbf_1"             
#> [49,] "rbf_2"             
#> [50,] "rbf_3"             
#> [51,] "tsne_5"            
#> [52,] "tsne_30"           
#> [53,] "tsne_50"           
#> [54,] "jaccard"           
#> [55,] "kulczynski1"       
#> [56,] "kulczynski2"       
#> [57,] "mountford"         
#> [58,] "russel"            
#> [59,] "simple_matching"   
#> [60,] "hamman"            
#> [61,] "faith"             
#> [62,] "phi"               
#> [63,] "michael"           
#> [64,] "mozley"            
#> [65,] "yule"              
#> [66,] "yule2"             
#> [67,] "ochiai"            
#> [68,] "simpson"           
#> [69,] "braun_blanquet"    
#> [70,] "chi_squared"       
#> [71,] "phi_squared"       
#> [72,] "tschuprow"         
#> [73,] "cramer"            
#> [74,] "pearson"           
#> [75,] "fidelity"          
#> [76,] "bhattacharyya"     
#> [77,] "hellinger"         
#> [78,] "matusita"          
#> [79,] "squared_chord"     
#> [80,] "jeffreys"          
#> [81,] "topsoe"            
#> [82,] "jensen_shannon"    
#> [83,] "jensen_difference" 
#> [84,] "taneja"            
#> [85,] "kumar_johnson"     
#> [86,] "prob_symm"         
#> [87,] "emd"               
#> [88,] "dtw"               
#> [89,] "frechet"           
#> [90,] "lcss"              
#> [91,] "edr"               

precise_dist_list(c("minkowski_dists")) %>%
  as.matrix()
#>      [,1]           
#> [1,] "euclidean"    
#> [2,] "supremum"     
#> [3,] "manhattan"    
#> [4,] "minkowski_0.5"
#> [5,] "minkowski_1.5"
#> [6,] "minkowski_2.5"